searchData={"items":[{"type":"module","title":"AshSqids.Type","doc":"`AshSqids.Type` implements `Ash.Type` behaviour in a module that `use`s it.\n\nBy default Sqids options are looked up by doing `Application.compile_env!(:ash_sqids, [:opts, __MODULE__])`.\n\n`use AshSqids.Type` accepts two optional exclusive options to change that - `opts` and `config`:\n- `opts` provides options directly and disables config lookup from environment.\n- `config` specifies a key to be used instead of a module name.\n\nHaving either options in config environment or in `opts` is required, even if you want to use default ones\n(in that case pass empty list `[]`).\n\nSqids options include `alphabet`, `min_length` and `blocklist`. It is recommended to provide `alphabet`.\nIt can be a default one - `abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789` - but just shuffled.","ref":"AshSqids.Type.html"},{"type":"extras","title":"Guide","doc":"# AshSqids\n\n[![Module Version](https://img.shields.io/hexpm/v/ash_sqids)](https://hex.pm/packages/ash_sqids)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-lightgreen)](https://hexdocs.pm/ash_sqids/)\n[![License](https://img.shields.io/hexpm/l/ash_sqids)](https://github.com/vonagam/ash_sqids/blob/master/LICENSE.md)\n\n[Sqids](https://sqids.org/) type for [Ash](https://ash-hq.org/) framework.\n\nFor what are Sqids and why would you want to use them I recommend looking at the linked website. But basically it is a pretty presentation for integer type. You might prefer having url like `/rooms/DcHPs` over `/rooms/151` or `/rooms/48922bf6-c418-4023-a478-0cca4dd04e68`.\n\nThe library consists of a single module `AshSqids.Type` that provides `Ash.Type` implementation.","ref":"readme.html"},{"type":"extras","title":"Installation - Guide","doc":"Add to the deps, get deps (`mix deps.get`), compile them (`mix deps.compile`).\n\n```elixir\ndef deps do\n  [\n    {:ash_sqids, \"~> 0.0.1\"},\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Usage - Guide","doc":"Define a module that will represent a Sqid type and `use AshSqids.Type` in it. Provide configuration for it in `config :ash_sqids, :opts`. And then use it as type in attributes and arguments.\n\n```elixir\n# lib/example/posts/resources/comment.ex\ndefmodule Example.Posts.Comment do\n  use Ash.Resource, data_layer: AshPostgres.DataLayer\n\n  # 1) define a type module\n  defmodule Id, do: use(AshSqids.Type)\n\n  attributes do\n    # 2) use it as an attribute type\n    integer_primary_key :id, type: Id\n\n    # ...\n  end\n\n  relationships do\n    # 3) use as `attribute_type` in `belongs_to` like this\n    belongs_to :post, Example.Posts.Post, attribute_type: Example.Posts.Post.Id\n  end\nend\n```\n\n#","ref":"readme.html#usage"},{"type":"extras","title":"Primary key - Guide","doc":"As shown if you want to use it as a primary key (main use case) then add `integer_primary_key` with `type` option.\n\nAnd don't forget `attribute_type` in `belongs_to` for references to a resource with sqids.\n\n#","ref":"readme.html#primary-key"},{"type":"extras","title":"Config - Guide","doc":"Here is how mentioned config is supposed to look:\n\n```elixir\n# config/config.exs\nimport Config\n\nconfig :ash_sqids, :opts, [\n  {Example.Posts.Comment.Id, []}, # use default options\n  {Example.Posts.Post.Id, min_length: 7} # some custom values\n]\n```\n\nOptions are passed into `Sqids.new!` and at the time of writing there are three options there -\n`alphabet`, `min_length` and `blocklist`.\n\nIt is better to provide alphabet. It can be a default one - `abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789` - but just shuffled.\n\n`use AshSqids.Type` accepts optional `config` option that allows you to reuse configurations.\nSo if in the example we wanted for comments ids and posts ids to be in the same style then we could do it like this:\n```elixir\n# `config` is an atom (defaulting to a module name) that will be used as a key\n# to look up Sqids options from `config :ash_sqids, :opts`\ndefmodule Id, do: use(AshSqids.Type, config: Example.Posts.Post.Id)\n```\n\n#","ref":"readme.html#config"},{"type":"extras","title":"Protocols - Guide","doc":"`AshSqids.Type` provides implementation for following protocols: \n- `String.Chars` - so `\"#{id}\"` results in a sqid string.\n- `Jason.Encoder` - same, returns a sqid string.\n- `Inspect` - with the format of `#Example.Posts.Comment.Id<1, \"Uk\">`.","ref":"readme.html#protocols"},{"type":"extras","title":"References - Guide","doc":"Sqids - [website](https://sqids.org/), [github](https://github.com/sqids), [elixir library](https://github.com/sqids/sqids-elixir).\n\nAsh - [website](https://ash-hq.org/), [github](https://github.com/ash-project), [`Ash.Type` docs](https://hexdocs.pm/ash/Ash.Type.html).","ref":"readme.html#references"},{"type":"extras","title":"License","doc":"MIT License\n\nCopyright (c) 2024 Dmitry Maganov\n\nPermission is hereby granted, free of charge, to any person obtaining a copy\nof this software and associated documentation files (the \"Software\"), to deal\nin the Software without restriction, including without limitation the rights\nto use, copy, modify, merge, publish, distribute, sublicense, and/or sell\ncopies of the Software, and to permit persons to whom the Software is\nfurnished to do so, subject to the following conditions:\n\nThe above copyright notice and this permission notice shall be included in all\ncopies or substantial portions of the Software.\n\nTHE SOFTWARE IS PROVIDED \"AS IS\", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR\nIMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,\nFITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE\nAUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER\nLIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,\nOUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE\nSOFTWARE.","ref":"license.html"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,49,46,50]}}